@@ -227,6 +227,7 @@ get_registered_event_listeners (SpiBridge *app)
                                          SPI_DBUS_PATH_REGISTRY,
                                          SPI_DBUS_INTERFACE_REGISTRY,
                                          "GetRegisteredEvents");
+  spi_global_app_data->events_initialized = TRUE;
   if (!message)
     return;
 
@@ -756,8 +757,6 @@ adaptor_init (gint * argc, gchar ** argv[])
   else
     get_registered_event_listeners (spi_global_app_data);
 
-  g_atexit (exit_func);
-
   return 0;
 }
 
